==> n3_sdk-1.3.1r03.zip: n3_sdk-1.3.1/lib/component/n3c_loader-1.0.0-min.js <==

N3C.LoaderCache=Class.cast({Static:{_KEY:0,_ID:0,_LS:null,getPath:function(s){if(s.indexOf("?")!=-1){s+="&";}
else{s+="?";}
return s+"%21n3c_id="+this._ID;},refresh:function(){var id=Date.now();var ls=this._LS;if(ls){try{ls.setItem(this._KEY+"_cache",id);}catch(e){}}
this._ID=id;},},Loader:function(){var key=window.location.pathname;var id=Date.now();try{var ls=window.localStorage;if(ls){this._LS=ls;var _id=ls.getItem(key+"_cache");if(_id){id=_id;}
else{ls.setItem(this._KEY+"_cache",id);}}}
catch(e){}
this._ID=id;this._KEY=key;}});N3C.ImageLoader=Class.cast({Static:{_IMAGES:null,_ERRS:null,_WCNT:0,start:function(srcs,m,p,cache,each){this._IMAGES=[];this._ERRS={};this._WCNT=srcs.length;for(var i=0,src;src=srcs[i];i++){if(!cache){src=N3C.LoaderCache.getPath(src);}
var ie=new Image();if(!each){this._IMAGES.push(new N3C.Image(null,ie));}
ie.src=src;if(ie.complete){N3C.ImageLoader._callback(ie,m,p,each,true);}
else{ie.addEventListener("load",function(e){N3C.ImageLoader._callback(e.target,m,p,each,true);},true);ie.addEventListener("error",function(e){N3C.ImageLoader._callback(e.target,m,p,each,false);},true);}}},_callback:function(ie,m,p,each,r){if(!r){this._ERRS[ie.src]=new N3C.Image(null,ie);}
var cls=N3C.ImageLoader;cls._WCNT--;if(each||cls._WCNT<=0){N3C.requestDisplayReady(function(){m.call(null,new N3C.Image(null,ie),p,r,cls._WCNT);});}},getWaitingCount:function(){return this._WCNT;},fetchImages:function(){var imgs=this._IMAGES;this._IMAGES=null;return imgs;},fetchErrors:function(){var errs=this._ERRS;this._ERRS=null;return errs;}}});N3C.ScriptLoader=Class.cast({Extends:N3C,Static:{_SCRIPTS:[],_NOTICES:{},_WCNT:0,_ERRS:[],start:function(srcs,m,p,cache){this._SCRIPTS=[];this._ERRS=[];for(var i=0,src;src=srcs[i];i++){this.download(src,m,p,!!cache);}
return this._SCRIPTS;},_finishLoad:function(m,p){this._WCNT--;if(this._WCNT<=0){this._SCRIPTS=[];if(m){m.call(null,p);}}},getWaitingCount:function(){return this._WCNT;},download:function(u,m,p,cache){var sc=new this(true)
this._SCRIPTS.push(sc);this._WCNT++;sc.setURL(u,cache).activate();if(m){sc.addLoadedListener(function(){N3C.ScriptLoader._finishLoad(m,p);});}
return sc;},generate:function(s,m,p,target){var sc=new this(true).setSource(s,m,p).activate();return sc},source:function(u,a){var s=N3C.LoaderCache.getPath(u);var async=a?"async":"";return"<script src=\""+s+"\" "+async+"></script>";},fetchErrors:function(){var errs=this._ERRS;this._ERRS=[];if(errs.length>0){return errs;}
return null;},_notified:function(k){var info=this._NOTICES[k];var m=info[0];var p=info[1];m.call(null,p);delete this._NOTICES[k];}},newInstance:function(async){var s=document.createElement("script");s.async=async;this.superClass(s);},addLoadedListener:function(m){var e=this.raw;e.addEventListener("load",m,true);e.addEventListener("error",function(e){N3C.ScriptLoader._ERRS.push({src:e.target.src,err:e});},true);return this;},setURL:function(url,cache){if(!cache){url=N3C.LoaderCache.getPath(url);}
this.raw.src=url;return this;},setSource:function(s,m,p){if(m){var k=Date.now();N3C.ScriptLoader._NOTICES[k]=[m,p];s+=" N3C.ScriptLoader._notified("+k+");";}
this.raw.text=s;return this;},activate:function(){N3C.headComponent().add(this);return this;}});N3C.StyleLoader=Class.cast({Extends:N3C,Static:{start:function(srcs){var q="?id="+Date.now();for(var i=0,src;src=srcs[i];i++){var linkObj=document.createElement("link");linkObj.rel="StyleSheet";linkObj.href=src+q;N3C.headComponent().raw.appendChild(linkObj);}},generate:function(src){return new this(src);}},newInstance:function(src){var so=document.createElement("style");so.appendChild(document.createTextNode(src));this.superClass(so);},activate:function(){N3C.headComponent().add(this);return this;}});

==> n3_sdk-1.3.3r03.zip: n3_sdk-1.3.3/lib/component/n3c_loader-1.0.0-min.js <==

N3C.LoaderCache=Class.cast({Static:{_KEY:0,_ID:0,_LS:null,getPath:function(s){if(s.indexOf("?")!=-1){s+="&";}
else{s+="?";}
return s+"%21n3c_id="+this._ID;},refresh:function(){var id=Date.now();var ls=this._LS;if(ls){try{ls.setItem(this._KEY+"_cache",id);}catch(e){}}
this._ID=id;},},Loader:function(){var key=window.location.pathname;var id=Date.now();try{var ls=window.localStorage;if(ls){this._LS=ls;var _id=ls.getItem(key+"_cache");if(_id){id=_id;}
else{ls.setItem(this._KEY+"_cache",id);}}}
catch(e){}
this._ID=id;this._KEY=key;}});N3C.ImageLoader=Class.cast({Static:{_IMAGES:null,_ERRS:null,_WCNT:0,start:function(srcs,m,p,cache,each){this._IMAGES=[];this._ERRS={};this._WCNT=srcs.length;var n3c=N3C;for(var i=0,src;src=srcs[i];i++){if(!cache){src=n3c.LoaderCache.getPath(src);}
var ie=new Image();if(!each){this._IMAGES.push(new n3c.Image(null,ie));}
ie.src=src;if(ie.complete){N3C.ImageLoader._callback(ie,m,p,each,true);}
else{ie.addEventListener("load",function(e){N3C.ImageLoader._callback(e.target,m,p,each,true);},true);ie.addEventListener("error",function(e){N3C.ImageLoader._callback(e.target,m,p,each,false);},true);}}},_callback:function(ie,m,p,each,r){if(!r){this._ERRS[ie.src]=new N3C.Image(null,ie);}
var cls=N3C.ImageLoader;cls._WCNT--;if(each||cls._WCNT<=0){N3C.requestDisplayReady(function(){m.call(null,new N3C.Image(null,ie),p,r,cls._WCNT);});}},getWaitingCount:function(){return this._WCNT;},fetchImages:function(){var imgs=this._IMAGES;this._IMAGES=null;return imgs;},fetchErrors:function(){var errs=this._ERRS;this._ERRS=null;return errs;}}});N3C.ScriptLoader=Class.cast({Extends:N3C,Static:{_SCRIPTS:[],_NOTICES:{},_WCNT:0,_ERRS:[],start:function(srcs,m,p,cache){this._SCRIPTS=[];this._ERRS=[];for(var i=0,src;src=srcs[i];i++){this.download(src,m,p,!!cache);}
return this._SCRIPTS;},_finishLoad:function(m,p){this._WCNT--;if(this._WCNT<=0){this._SCRIPTS=[];if(m){m.call(null,p);}}},getWaitingCount:function(){return this._WCNT;},download:function(u,m,p,cache){var sc=new this(true)
this._SCRIPTS.push(sc);this._WCNT++;sc.setURL(u,cache).activate();if(m){sc.addLoadedListener(function(){N3C.ScriptLoader._finishLoad(m,p);});}
return sc;},generate:function(s,m,p,target){var sc=new this(true).setSource(s,m,p).activate();return sc},source:function(u,a){var s=N3C.LoaderCache.getPath(u);var async=a?"async":"";return"<script src=\""+s+"\" "+async+"></script>";},fetchErrors:function(){var errs=this._ERRS;this._ERRS=[];if(errs.length>0){return errs;}
return null;},_notified:function(k){var info=this._NOTICES[k];var m=info[0];var p=info[1];m.call(null,p);delete this._NOTICES[k];}},newInstance:function(async){var s=document.createElement("script");s.async=async;this.superClass(s);},addLoadedListener:function(m){var e=this.raw;e.addEventListener("load",m,true);e.addEventListener("error",function(e){N3C.ScriptLoader._ERRS.push({src:e.target.src,err:e});},true);return this;},setURL:function(url,cache){if(!cache){url=N3C.LoaderCache.getPath(url);}
this.raw.src=url;return this;},setSource:function(s,m,p){if(m){var cls=N3C.ScriptLoader,k=Date.now();cls._NOTICES[k]=[m,p];s+=" cls._notified("+k+");";}
this.raw.text=s;return this;},activate:function(){N3C.headComponent().add(this);return this;}});N3C.StyleLoader=Class.cast({Extends:N3C,Static:{start:function(srcs){var q="?id="+Date.now();for(var i=0,src;src=srcs[i];i++){var linkObj=document.createElement("link");linkObj.rel="StyleSheet";linkObj.href=src+q;N3C.headComponent().raw.appendChild(linkObj);}},generate:function(src){return new this(src);}},newInstance:function(src){var so=document.createElement("style");so.appendChild(document.createTextNode(src));this.superClass(so);},activate:function(){N3C.headComponent().add(this);return this;}});
